@@ -79,9 +79,9 @@ function get_userdata( $user_id ) {
 	if ( !$user = $wpdb->get_row("SELECT * FROM $wpdb->users WHERE ID = '$user_id' LIMIT 1") )
 		return false;
 
-	$wpdb->hide_errors();
+	$show = $wpdb->hide_errors();
 	$metavalues = $wpdb->get_results("SELECT meta_key, meta_value FROM $wpdb->usermeta WHERE user_id = '$user_id'");
-	$wpdb->show_errors();
+	$wpdb->show_errors($show);
 
 	if ($metavalues) {
 		foreach ( $metavalues as $meta ) {
@@ -341,7 +341,7 @@ function wp_login($username, $password, $already_md5 = false) {
 	} else {
 		if( is_site_admin( $username ) == false && ( $primary_blog = get_usermeta( $login->ID, "primary_blog" ) ) ) {
 			$details = get_blog_details( $primary_blog );
-			if( is_object( $details ) && $details->archived == 1 || $details->spam == 1 || $details->deleted == 1 ) {
+			if( is_object( $details ) && $details->spam == 1 ) {
 				$error = __('<strong>Error</strong>: Blog suspended.');
 				return false;
 			}
